import 'package:flutter/material.dart';
import 'package:syncfusion_flutter_charts/charts.dart';
import 'package:intl/intl.dart';

void main() {
  runApp(const MyApp());
}

class MyApp extends StatelessWidget {
  const MyApp({super.key});

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      title: 'Flutter Demo',
      theme: ThemeData(
        primarySwatch: Colors.blue,
      ),
      home: const MyHomePage(title: 'Flutter Demo Home Page'),
    );
  }
}

class MyHomePage extends StatefulWidget {
  const MyHomePage({super.key, required this.title});
  final String title;

  @override
  State<MyHomePage> createState() => _MyHomePageState();
}

class _MyHomePageState extends State<MyHomePage> {
  final List<ChartData> chartData = [
    ChartData(DateTime(2022, 10, 12, 8), 30),
    ChartData(DateTime(2022, 10, 13), 30),
    ChartData(DateTime(2022, 10, 14), 28),
    ChartData(DateTime(2022, 10, 15), 34),
    ChartData(DateTime(2022, 10, 16, 16, 32), 33),
    ChartData(DateTime(2022, 10, 17), 32),
    ChartData(DateTime(2022, 10, 18), 22),
    ChartData(DateTime(2022, 10, 19), 24),
  ];
  late ZoomPanBehavior _zoomPanBehavior;
  DateTime? vis_min;
  DateTime? vis_max;
  @override
  void initState() {
    _zoomPanBehavior = ZoomPanBehavior(
      enablePanning: true,
      enableMouseWheelZooming: true,
    );
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: Column(
        children: <Widget>[
          SfCartesianChart(
            onActualRangeChanged: (args) {
              if (args.orientation == AxisOrientation.horizontal) {
                vis_min = DateTime.fromMillisecondsSinceEpoch(args.visibleMin);
                vis_max = DateTime.fromMillisecondsSinceEpoch(args.visibleMax);
              }
            },
            primaryXAxis: DateTimeAxis(
              visibleMinimum: vis_min ?? chartData[3].x,
              visibleMaximum: vis_max ?? chartData[chartData.length - 1].x,
              edgeLabelPlacement: EdgeLabelPlacement.shift,
              dateFormat: DateFormat('MMM dd'),
            ),
            primaryYAxis: NumericAxis(minimum: 20),
            zoomPanBehavior: _zoomPanBehavior,
            series: <ChartSeries>[
              StepLineSeries<ChartData, DateTime>(
                animationDuration: 0,
                dataSource: chartData,
                xValueMapper: (ChartData data, _) => data.x,
                yValueMapper: (ChartData data, _) => data.y,
              ),
            ],
          ),
          TextButton(
            child: Text('Show'),
            onPressed: () {
              setState(() {});
            },
          ),
        ],
      ),
    );
  }
}

class ChartData {
  ChartData(this.x, this.y);
  final DateTime x;
  final double? y;
}
